[GitHub Pages](https://amerenicenter.github.io/snake/)

# snake

# Installing

## Option 1
**Install via pip**
```
pip install icenter_snake
```

## Option 2
**Clone the GitHub repository**
```
git clone https://github.com/AmerenICenter/snake.git
```

# Usage

## Option 1
**Run the main script from terminal**
```
python snake_main.py
```

## Option 2
**Run as a module from terminal**
```
python -m snake
```
*Note: this calls `src/__main__.py`*

## Option 3
**Import the package within a python script**
```python
import snake
snake.run()
```


# Authors
Archit Myadam,
David An,
Jash Parekh,
Myles Ream,
Xander Pero,
Jack Aubry,
Ritika Patel
